# Fact Sheet Owner Onboarding Dashboard
### On this page
  * [Introduction](https://help.sap.com/docs/leanix/ea/fact-sheet-owner-onboarding-dashboard#introduction)
  * [Activating the Dashboard](https://help.sap.com/docs/leanix/ea/fact-sheet-owner-onboarding-dashboard#activating-the-dashboard)
  * [Dashboard Structure](https://help.sap.com/docs/leanix/ea/fact-sheet-owner-onboarding-dashboard#dashboard-structure)


The Fact Sheet Owner onboarding dashboard helps new users learn SAP LeanIX. It offers resources and panels for understanding responsibilities, managing data, and collaborating. It's the default dashboard for new workspaces, featuring tutorials and links to product documentation.
